<?php
// Version: 1.1.3; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1.3';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = false;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = false;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', ' lang="', $txt['lang_locale'], '"><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />
	<meta name="keywords" content="PHP, MySQL, smf, simple, machines, forum" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The ?11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/global.css" media="screen" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/', css_selector(), '.css" media="screen" />
	<!--[if lte IE 6]><link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/ie6lte.css" /><![endif]-->
	<!--[if IE 7]><link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/ie7.css" /><![endif]-->
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/print.css" media="print" />';

	// The stylesheet for the right-to-left languages
		  if (!empty($context['right_to_left']))
		echo '
		  <link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/rtl.css?11" media="screen" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'];
	
		  echo '
</head>
<body>';
echo'
	<div id="wrapper">
		<div id="header">';

		  // The Blog heading and the description
		  echo '
			<h1><a href="', $scripturl, '" title="', $context['forum_name'], '">', $context['forum_name'], '</a></h1>';

		  // The default value for the description text
	if (empty($settings['forum_description']))
	{
		$settings['forum_description'] = 'You can edit this from "Admin CP > Current Theme"';
	}
	
	echo '
			<p>', $settings['forum_description'], '</p>';
			  
		  // These two links have been added for accesibility, they will not be shown under normal circumstances
	echo '
				  <h2>', $txt['forsakenlad_access'], '</h2>
			<ul id="access">
				<li><a href="#topnav">', $txt['forsakenlad_access_nav'], '</a></li>
				<li><a href="#bodyarea">', $txt['forsakenlad_access_con'], '</a></li>
			</ul>';
			
	// The navigation menu
	echo '
			<h2>', $txt['forsakenlad_navigation'], '</h2>
			', template_menu();

		  echo '
		</div>
		<h2>', $txt['forsakenlad_maincontent'], '</h2>
		<div id="bodyarea">';

	 // Is the forum in maintenance mode?
	if ($context['in_maintenance'] && $context['user']['is_admin'])
		echo '
			<p style="text-align: center; position: relative;"><strong>', $txt[616], '</strong></p>';
	// Are there any members waiting for approval?
	if (!empty($context['unapproved_members']))
		echo '
			<p style="text-align: center; position: relative;">', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '</p>';

}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
			<div style="clear: both;"></div>
			<p id="footer">
				', theme_copyright(), '
				<br /><span><a href="http://validator.w3.org/check/referer" title="', $txt['valid_xhtml'], '" target="_blank">XHTML 1.0</a> | <a href="http://jigsaw.w3.org/css-validator/check/referer?warning=no" title="', $txt['valid_css'], '" target="_blank">CSS 2</a> | <a href="http://www.contentquality.com/mynewtester/cynthia.exe?Url1=' . $scripturl . '&amp;rptmode=2&amp;warnp2n3e=1" title="Valid WCAG 1.0 Priority 1, 2 and 3!" target="_blank">WCAG 1.0</a></span>';

	// Show the load time?
	if ($context['show_load_time'])
		echo '
				<br />', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'];

	echo '
								</p>
		</div>
		<div id="bottom"></div>
	</div>';

	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_center"><div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div></div>
</body>
</html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '
		<div class="nav">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '">' . $tree['name'] . '</a>' : $tree['name'];

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;|&nbsp;';
	}

	echo '</div>';
}

// This one selects stylesheets for different templates
function css_selector()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$template = 'common';

	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$template = $context['current_action'];
		
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$template = 'admin';

	if ($context['current_action'] == 'login2')
		$template = 'login';

	if ($context['current_action'] == 'search2')
		$template = 'search';
		
	echo $template;

}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';

	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';

	// The start of the first list
	echo '<ul id="topnav">';

	// Show the [home] button.
	echo '<li' , $current_action == 'home' ? ' id="active"' : '', '><a class="home" href="', $scripturl, '">' , $txt[103] , '</a></li>';

	// How about the [search] button?
	if ($context['allow_search'])
		echo '<li' , $current_action == 'search' ? ' id="active"' : '', '><a class="search" href="', $scripturl, '?action=search">' , $txt[182] , '</a></li>';

	// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		echo '<li' , $current_action == 'admin' ? ' id="active"' : '', '><a class="admin"  href="', $scripturl, '?action=admin">' , $txt[2] , '</a></li>';

	// The [calendar]!
	if ($context['allow_calendar'])
		echo '<li' , $current_action == 'calendar' ? ' id="active"' : '', '><a class="calendar" href="', $scripturl, '?action=calendar">' , $txt['calendar24'] , '</a></li>';

	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		echo '<li' , $current_action == 'profile' ? ' id="active"' : '', '><a class="profile" href="', $scripturl, '?action=profile">' , $txt[79] , '</a></li>';

	// Go to PM center... [pm]
	if ($context['user']['is_logged'] && $context['allow_pm'])
		echo '<li' , $current_action == 'pm' ? ' id="active"' : '', '><a class="pm" href="', $scripturl, '?action=pm">' , $txt['pm_short'] , '', $context['user']['unread_messages'] > 0 ? '['. $context['user']['unread_messages'] . ']' : '' , '</a></li>';

	// If the user is a guest, show [login] button.
	if ($context['user']['is_guest'])
		echo '<li' , $current_action == 'login' ? ' id="active"' : '', '><a class="login" href="', $scripturl, '?action=login">' , $txt[34] , '</a></li>';

	// If the user is a guest, also show [register] button.
	if ($context['user']['is_guest'])
		echo '<li' , $current_action == 'register' ? ' id="active"' : '', '><a class="register" href="', $scripturl, '?action=register">' , $txt[97] , '</a></li>';

	// Otherwise, they might want to [logout]...
	if ($context['user']['is_logged'])
		echo '<li><a class="logout" href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">' , $txt[108] , '</a></li>';

	// The end of the second list.
	echo '</ul>';

}

?>